/**
 * EasyBeans
 * Copyright (C) 2008 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: PoolConfigurationHelper.java 2789 2008-04-03 17:59:37Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.pool.impl;

import org.ow2.util.pool.annotation.Pool;
import org.ow2.util.pool.api.IPoolConfiguration;

/**
 * Helper class that extracts data from annotation and returns a {@link PoolConfiguration} object.
 * @author Florent BENOIT
 */
public final class PoolConfigurationHelper {

    /**
     * Utility class, no public constructor.
     */
    private PoolConfigurationHelper() {

    }

    /**
     * Allow to return a configuration for the pool by extracting data from the {@link Pool} annotation.
     * @param poolAnnotation the given Pool annotation to analyze
     * @return a PoolConfiguration instance
     */
    public static IPoolConfiguration getConfiguration(final Pool poolAnnotation) {
        // Create object
        PoolConfiguration poolConfiguration = new PoolConfiguration();

        // Analyze values of the annotation
        poolConfiguration.setMax(poolAnnotation.max());
        poolConfiguration.setMaxWaiters(poolAnnotation.maxWaiters());
        poolConfiguration.setTimeout(poolAnnotation.timeout());

        return poolConfiguration;
    }
}
